@@ -42,7 +42,6 @@
 #include<arpa/nameser.h>
 #include<resolv.h>
 #include<sys/utsname.h>
-#include<isc/util.h>
 #include<unistd.h>
 #include<signal.h>
 #include<sys/signal.h>
@@ -174,9 +173,12 @@ int db_reload(void) {
 	if(fp==NULL) return(0);
 	while(fgets(str,1024,fp)!=NULL) {
 	 off_nl(str);
+
+	 if(strchr(line_entry(1,str),';')==NULL)
 	 if(!strcmp(line_entry(2,str),"{")) {
 
 		unsigned char keyword[256];
+		char *cp;
 
 		rec=(db_t *)malloc(sizeof(db_t));
 		if(rec==NULL) { fclose(fp); return(0); }
@@ -188,9 +190,16 @@ int db_reload(void) {
 		strcpy(keyword,line_entry(1,str));
 		strtolower(keyword);
 
-		if(!strcmp(keyword,"hostname"))
+		if(!strcmp(keyword,"hostname")) {
 			strcpy(rec->fqdn,line_entry(2,str));
 
+			// Take leading text if comment character found
+			if((cp=strchr(rec->fqdn,';'))!=NULL)
+				*cp='\0';
+		}
+
+
+
 		} while(strcmp(line_entry(1,str),"}"));
 		if(rec->fqdn[0]=='\0') continue;
 		db_add(rec);
